Struct muse_ui::DynamicValue

source ·
pub struct DynamicValue(pub Dynamic<Value>);

Tuple Fields

0: Dynamic<Value>

Methods from Deref<Target = Dynamic<Value>>

pub fn downgrade(&self) -> WeakDynamic<T>

Returns a weak reference to this dynamic.

This is powered by Arc/Weak and follows the same semantics for reference counting.

pub fn instances(&self) -> usize

Returns the number [Dynamic]s that point to this same value.

The returned count includes self.

Panics

This function panics if this value is already locked by the current thread.

pub fn readers(&self) -> usize

Returns the number of [DynamicReader]s for this value.

Panics

This function panics if this value is already locked by the current thread.

pub fn linked<R, TIntoR, TIntoRResult, RIntoT, RIntoTResult>( &self, t_into_r: TIntoR, r_into_t: RIntoT, ) -> Dynamic<R>
where T: PartialEq + Send + 'static, R: PartialEq + Send + 'static, TIntoRResult: Into<Option<R>> + Send + 'static, RIntoTResult: Into<Option<T>> + Send + 'static, TIntoR: FnMut(&T) -> TIntoRResult + Send + 'static, RIntoT: FnMut(&R) -> RIntoTResult + Send + 'static,

Returns a new dynamic that has its contents linked with self by the pair of mapping functions provided.

When the returned dynamic is updated, r_into_t will be invoked. This function accepts &R and can return T, or Option<T>. If a value is produced, self will be updated with the new value.

When self is updated, t_into_r will be invoked. This function accepts &T and can return R or Option<R>. If a value is produced, the returned dynamic will be updated with the new value.

Panics

This function panics if calling t_into_r with the current contents of the Dynamic produces a None value. This requirement is only for the first invocation, and it is guaranteed to occur before this function returns.

pub fn linked_string(&self) -> Dynamic<String>
where T: ToString + FromStr + PartialEq + Send + 'static,

Creates a linked dynamic containing a String.

When self is updated, ToString::to_string() will be called to produce a new string value to store in the returned dynamic.

When the returned dynamic is updated, str::parse is called to produce a new T. If an error is returned, self will not be updated. Otherwise, self will be updated with the produced value.

pub fn set_source(&self, source: CallbackHandle)

Sets the current source for this dynamic with source.

A dynamic can have multiple source callbacks.

This ensures that source stays active as long as any clones of self are alive.

pub fn with_clone<R>(&self, with_clone: impl FnOnce(Dynamic<T>) -> R) -> R

A helper function that invokes with_clone with a clone of self. This code may produce slightly more readable code.

use cushy::value::{Dynamic, Source};

let value = Dynamic::new(1);

// Using with_clone
value.with_clone(|value| {
    std::thread::spawn(move || {
        println!("{}", value.get());
    })
});

// Using an explicit clone
std::thread::spawn({
    let value = value.clone();
    move || {
        println!("{}", value.get());
    }
});

println!("{}", value.get());

pub fn create_reader(&self) -> DynamicReader<T>

Returns a new reference-based reader for this dynamic value.

Panics

This function panics if this value is already locked by the current thread.

pub fn lock(&self) -> DynamicGuard<'_, T>

Returns an exclusive reference to the contents of this dynamic.

This call will block until all other guards for this dynamic have been dropped.

Panics

This function panics if this value is already locked by the current thread.

pub fn try_lock(&self) -> Result<DynamicGuard<'_, T>, DeadlockError>

Returns an exclusive reference to the contents of this dynamic.

This call will block until all other guards for this dynamic have been dropped.

Errors

Returns an error if the current thread already holds a lock to this dynamic.

pub fn transition_to(&self, new_value: T) -> DynamicTransition<T>
where T: LinearInterpolate + Clone + Send + Sync,

Returns a pending transition for this value to new_value.

pub fn new_radio(&self, widget_value: T, label: impl MakeWidget) -> Radio<T>
where Dynamic<T>: Clone, T: Clone + PartialEq,

Returns a new [Radio] that updates this dynamic to widget_value when pressed. label is drawn next to the checkbox and is also clickable to select the radio.

pub fn new_select(&self, widget_value: T, label: impl MakeWidget) -> Select<T>
where Dynamic<T>: Clone, T: Clone + PartialEq,

Returns a new [Select] that updates this dynamic to widget_value when pressed. label is drawn next to the checkbox and is also clickable to select the widget.

pub fn validate_with<E, Valid>(&self, check: Valid) -> Dynamic<Validation>
where T: Send + 'static, Valid: for<'a> FnMut(&'a T) -> Result<(), E> + Send + 'static, E: Display,

Validates the contents of this dynamic using the check function, returning a dynamic that contains the validation status.

pub fn to_switcher(&self) -> Switcher

Returns a new [Switcher] widget whose contents is the value of this dynamic.

pub fn to_rows(&self) -> Stack

Returns self as a vertical [Stack] of rows.

pub fn to_columns(&self) -> Stack

Returns self as a horizontal [Stack] of columns.

pub fn to_layers(&self) -> Layers

Returns self as [Layers], with the widgets being stacked in the Z direction.

pub fn to_wrap(&self) -> Wrap

Returns a [Wrap] that lays the children out horizontally, wrapping into additional rows as needed.